# 🇹🇼 Taiwan Invoice

[![PyPI](https://img.shields.io/pypi/v/tw_invoice?color=brightgreen&logo=pypi&logoColor=white)](https://pypi.org/project/tw_invoice)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tw_invoice?color=brightgreen&logo=python&logoColor=white)
![PyPI - Downloads](https://img.shields.io/pypi/dm/tw_invoice?color=brightgreen)
![PyPI - License](https://img.shields.io/pypi/l/tw_invoice?color=brightgreen)

[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/tomy0000000/tw-invoice/test.yml?branch=main&logo=Github)](https://github.com/tomy0000000/tw-invoice/actions/workflows/test.yml)
[![Coverage](https://img.shields.io/codecov/c/github/tomy0000000/tw-invoice?color=brightgreen&logo=codecov&logoColor=white&token=ESgHfrrk6z)](https://codecov.io/gh/tomy0000000/tw-invoice)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/tomy0000000/tw-invoice/main.svg)](https://results.pre-commit.ci/latest/github/tomy0000000/tw-invoice/main)

[中文版 README](https://github.com/tomy0000000/tw-invoice/blob/main/README_zh.md)

SDK for Ministry of Finance, R.O.C. [E-invoice platform](https://www.einvoice.nat.gov.tw)

## Usage

See [Wiki](https://github.com/tomy0000000/tw-invoice/wiki)

## LICENSE and disclaimer

The source code is released under MIT license, versions with suffix b represent beta version, use at your own risk.

The author is not affiliated to MoF, or the platform in any kind.
